@@ -1,4 +1,5 @@
 from typing import Optional, List, Any, Dict
+
 from pydantic import BaseModel, Field
 
 
@@ -32,17 +33,27 @@ class Term(BaseModel):
         example={"altForms": ["basalt", "granite", "slate"], "wikidataId": "Q8063"},
     )
 
-    def __eq__(self, other):
+    def __eq__(self, other):  # noqa: E126
         return (
             other
-            and self.lexicon == other.lexicon   # noqa: W503
-            and self.identifier == other.identifier   # noqa: W503
+            and self.lexicon == other.lexicon  # noqa: W503
+            and self.identifier == other.identifier  # noqa: W503
         )
 
     def __hash__(self):
         return hash((self.identifier, self.lexicon))
 
 
+class AltText(BaseModel):
+    name: str = Field(
+        None, description="Name of the alternative text", example="fingerprint"
+    )
+    text: str = Field(None, description="Alternative text")
+    properties: Optional[Dict[str, Any]] = Field(
+        None, description="Properties of the alternative text"
+    )
+
+
 class Annotation(Span):
     labelName: str = Field(
         None, description="Label name of the annotation", example="org"
@@ -113,6 +124,9 @@ class Document(BaseModel):
         None, description="List of boundaries by type"
     )
     metadata: Optional[Dict[str, Any]] = Field(None, description="Document metadata")
+    altTexts: Optional[List[AltText]] = Field(
+        None, description="Document alternative texts"
+    )
     properties: Optional[Dict[str, Any]] = Field(
         None, description="Document properties"
     )
